slidgram
========

A
`feature-rich <https://slidge.im/docs/slidgram/main/features.html>`_
`Telegram <https://telegram.org>`_ to
`XMPP <https://xmpp.org/>`_ puppeteering
`gateway <https://xmpp.org/extensions/xep-0100.html>`_, based on
`slidge <https://slidge.im>`_ and
`Pyrofork <https://pyrofork.mayuri.my.id/main/>`_.

.. toctree::
   :maxdepth: 3

   readme
   features
   config
   user
   autoapi/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
